package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````8!,``#0```"4D0````0`!30`(``*
M`"@`&P`:``$``'"(AP``B(<``(B'```(````"`````0````$````!@```#0`
M```T````-````$`!``!``0``!`````0````#````F`$``)@!``"8`0``&0``
M`!D````$`````0````$```````````````````"TAP``M(<```4`````$```
M`0```+R-``"\G0``O)T``(P"``"@`@``!@`````0```"````Q(T``,2=``#$
MG0``"`$```@!```&````!`````0```!T`0``=`$``'0!```D````)`````0`
M```$````!````)2'``"4AP``E(<``"`````@````!`````0```!1Y71D````
M```````````````````````&````$````%+E=&2\C0``O)T``+R=``!$`@``
M1`(```0````!````!````!0````#````1TY5`",^7(`.%;VM"I\G*WKQ#OUH
M@;!F+VQI8B]L9"UL:6YU>"UA<FUH9BYS;RXS``````$````!`````0``````
M````````````````````````````````````````H`T````````#``H`````
M``"@`````````P`6`!("`````````````!(```!Q```````````````2````
MZ@(`````````````$@```+4"`````````````!(```"G`@`````````````2
M````>P``````````````$@```(H!`````````````!(```"'````````````
M```2`````0``````````````(````*`"`````````````!(```"Y````````
M```````2````80``````````````$@```*X"`````````````!(```#G````
M```````````2````U`$`````````````$@```!```````````````"````#<
M```````````````2````O0(`````````````$@```'8``````````````!(`
M`````@`````````````2````Q`(`````````````$@```"P`````````````
M`"````!J`@`````````````2````!0(`````````````$@```%,`````````
M`````!(````G`0`````````````6````!`$`````````````$@```&H!````
M`````````!(```"H```````````````2````]0``````````````$@```/,!
M`````````````!(```#<`0`````````````2````RP(`````````````$@``
M`.H!`````````````!(```#-```````````````2````^@(`````````````
M$0```,T!`````````````!(````4`P`````````````1````&`(`````````
M````$@```)H``````````````!(```#$`0`````````````2````O0$`````
M````````$@```%X!`````````````!(```"K`0`````````````2````(`$`
M````````````$@```)4!`````````````!(```!;`@`````````````2````
MXP$`````````````$@```/H!`````````````!(```!I`@`````````````2
M`````@,`````````````$@```#H!`````````````!(````G`@``````````
M```2````%`$`````````````$@```"X"`````````````!(```#X`@``````
M```````1````@P(`````````````$0```$8``````````````!$```"S`0``
M```````````2````3P$`````````````$0```#\"`````````````!(```#P
M`@`````````````2````P@``````````````$@```$T"`````````````!(`
M```W`@`````````````2````>P$`````````````$@```'$"````````````
M`!(```"*`@`````````````2````T@(`````````````$@```*8!````````
M`````!(```#9`@`````````````2````D0(`````````````(@````!?7V=M
M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R
M96=I<W1E<E1-0VQO;F5486)L90!03%]D;U]U;F1U;7``4&5R;%]S>7-?=&5R
M;0!097)L7V=V7V9E=&-H<'8`<&5R;%]F<F5E`%!E<FQ?9V5T7W-V`%!E<FQ?
M871F;W)K7W5N;&]C:P!P97)L7V1E<W1R=6-T`%!E<FQ?;F5W6%-?9FQA9W,`
M<&5R;%]R=6X`4&5R;%]N97=84P!097)L7W-V7W-E='!V;@!P97)L7V%L;&]C
M`%!E<FQ?<W9?<V5T<'8`<&5R;%]C;VYS=')U8W0`8F]O=%]$>6YA3&]A9&5R
M`%!E<FQ?<V%F97-Y<VUA;&QO8P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]C
M<F]A:U]N;V-O;G1E>'0`4$Q?;65M;W)Y7W=R87``4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?;&]C:P!097)L7W-Y<U]I;FET,P!P97)L7W!A<G-E`%]?<W1A
M8VM?8VAK7V9A:6P`97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO
M<V5D:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK`'-T<G1O:P!G971P=W5I9`!S
M=')L96X`<FUD:7(`<F5A9`!?7VUE;6-P>5]C:&L`;6MD:7(`7U]V9G!R:6YT
M9E]C:&L`9V5T<&ED`')E861L:6YK`')E86QL;V,`7U]S<')I;G1F7V-H:P!?
M7VUE;6UO=F5?8VAK`%]?9G!R:6YT9E]C:&L`;'-T870V-`!?7VQI8F-?<W1A
M<G1?;6%I;@!S=&1E<G(`;65M8VAR`%]?8WAA7V9I;F%L:7IE`'-T<F-H<@!M
M96UC;7``;65M<V5T`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC<'D`<W1R
M8VUP`%]?97)R;F]?;&]C871I;VX`86)O<G0`<W1R;F-M<`!?7V5N=FER;VX`
M7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS
M;RXU+C0P`&QI8F,N<V\N-@!L9"UL:6YU>"UA<FUH9BYS;RXS`$=,24)#7S(N
M-`!'3$E"0U\R+C,T`$=,24)#7S(N,S,``````````@`!``(``@`"``$``0`!
M``$``@`!``$``@`!``(``0`!``(``@`"``(``0`#``(``0`!``$``0`!``$`
M`@`"``(``@`!``(``@`$``(``0`"``(``0`"``(``@`"``(``@`#``(``0`"
M``$``@`"``(``0`"``$``@`"``$``@`"``$`!0`"``(``@`"``(````!``$`
M0`,``!`````@````%&EI#0``!`!4`P````````$``P`V`P``$`````````"T
MD98&```%`%X#```0````LY&6!@```P!I`P``$````!1I:0T```(`5`,`````
M``"\G0``%P```,"=```7````_)\``!<````$H```%P```!2@```7````&*``
M`!<````@H```%P```"2@```7````**```!<````LH```%P```#"@```7````
M.*```!<````\H```%P```$2@```7````R)\``!4*``#,GP``%0L``-"?```5
M$@``U)\``!48``#8GP``$QP``-R?```5'0``X)\``!4>``#DGP``%28``.B?
M```5*```[)\``!4[``#PGP``%3P``/2?```5/@``^)\``!5*``#8G@``%@,`
M`-R>```6!```X)X``!8%``#DG@``%@8``.B>```6!P``[)X``!8(``#PG@``
M%@D``/2>```6"P``^)X``!8,``#\G@``%@T```"?```6#@``!)\``!8/```(
MGP``%A````R?```6$0``$)\``!83```4GP``%A0``!B?```6%0``')\``!86
M```@GP``%A<``"2?```6&0``*)\``!8:```LGP``%AL``#"?```6'P``-)\`
M`!8@```XGP``%B$``#R?```6(@``0)\``!8C``!$GP``%B0``$B?```6)0``
M3)\``!8G``!0GP``%BD``%2?```6*@``6)\``!8K``!<GP``%BP``&"?```6
M+0``9)\``!8N``!HGP``%B\``&R?```6,```<)\``!8Q``!TGP``%C(``'B?
M```6,P``?)\``!8T``"`GP``%C4``(2?```6-@``B)\``!8W``",GP``%C@`
M`)"?```6.0``E)\``!8]``"8GP``%C\``)R?```60```H)\``!9!``"DGP``
M%D(``*B?```60P``K)\``!9$``"PGP``%D4``+2?```61@``N)\``!9'``"\
MGP``%D@``,"?```620``Q)\``!9*```(0"WI?@$`ZPB`O>@$X"WE!."?Y0[@
MC^`(\+[E$)$```#&C^()RHSB$/&\Y0#&C^()RHSB"/&\Y0#&C^()RHSB`/&\
MY0#&C^()RHSB^/"\Y0#&C^()RHSB\/"\Y0#&C^()RHSBZ/"\Y0#&C^()RHSB
MX/"\Y0#&C^()RHSBV/"\Y0#&C^()RHSBT/"\Y0#&C^()RHSBR/"\Y0#&C^()
MRHSBP/"\Y0#&C^()RHSBN/"\Y0#&C^()RHSBL/"\Y0#&C^()RHSBJ/"\Y0#&
MC^()RHSBH/"\Y0#&C^()RHSBF/"\Y0#&C^()RHSBD/"\Y0#&C^()RHSBB/"\
MY0#&C^()RHSB@/"\Y0#&C^()RHSB>/"\Y0#&C^()RHSB</"\Y0#&C^()RHSB
M:/"\Y0#&C^()RHSB8/"\Y0#&C^()RHSB6/"\Y0#&C^()RHSB4/"\Y0#&C^()
MRHSB2/"\Y0#&C^()RHSB0/"\Y0#&C^()RHSB./"\Y0#&C^()RHSB,/"\Y0#&
MC^()RHSB*/"\Y0#&C^()RHSB(/"\Y0#&C^()RHSB&/"\Y0#&C^()RHSB$/"\
MY0#&C^()RHSB"/"\Y0#&C^()RHSB`/"\Y0#&C^((RHSB^/^\Y0#&C^((RHSB
M\/^\Y0#&C^((RHSBZ/^\Y0#&C^((RHSBX/^\Y0#&C^((RHSBV/^\Y0#&C^((
MRHSBT/^\Y0#&C^((RHSBR/^\Y0#&C^((RHSBP/^\Y0#&C^((RHSBN/^\Y0#&
MC^((RHSBL/^\Y0#&C^((RHSBJ/^\Y0#&C^((RHSBH/^\Y0#&C^((RHSBF/^\
MY0#&C^((RHSBD/^\Y0#&C^((RHSBB/^\Y0#&C^((RHSB@/^\Y0#&C^((RHSB
M>/^\Y0#&C^((RHSB</^\Y0#&C^((RHSB:/^\Y0#&C^((RHSB8/^\Y0#&C^((
MRHSB6/^\Y0#&C^((RHSB4/^\Y0#&C^((RHSB2/^\Y0#&C^((RHSB0/^\Y0#&
MC^((RHSB./^\Y3!`+>ELPI_E+-!-XF@RG^4<`(WE&!"-Y10@C>4,P(_@`S"<
MYQ@0C>(4((WB'`"-XDA"G^4`,)/E)#"-Y0`PH./9___K."*?Y01`C^`"()3G
M,#*?Y0P@C>4#,)3G`A"@X0,`H.$0,(WE'0T`ZQ@RG^4#,)3G`##3Y0``4^-3
M```*<"\=[@0RG^4<$)WE`S"?YP0`@>(#()+G!P%PX\XSTN4#,(/CSC/"Y68`
M`(H``:#A`U"!XJ3__^L`,*#AT!&?Y=`AG^4!$(_@`$"1Y0(@C^`8$)WEP,&?
MY<`!G^4$,(+E'""=Y0#@D>4,P(_@``"/X`$`4N,$P(/E"$"#Y0#@@^4,`(/E
M5@``V@3@0>(,`(/B`N&.X`3`L>4!`%[A!,"@Y?O__QH#P(+B`."@XW!!G^5P
M$9_E!$"/X`P`E.4,X8/G!2"@X0$0C^``X(WE"?__ZP``4.,L```*3$&?Y01`
MC^`,`)3E3O__ZP!0H.$\`9_E(!"-X@``C^`,$(WEK0``ZP``4.,,$)WE(@``
M"B`QG^4#,(_@#`"3Y>?^_^LB___K$"&?Y=`PG^4"((_@`S"2YP`@D^4D,)WE
M`B`SX``PH.,K```:!0"@X2S0C>(P@+WH##"-Y?_^_^O<()_E``!0XP(@C^`,
M`(+E'P``"A3__^MP+QWNQ!"?Y0PPG>4!$)_G`1"2YW8VP>6=___J#`"4Y>'^
M_^O/___J"`"4Y0``4.,!```*=@@`Z]?__^J0`)_E``"/X'\``.L``%#C"`"$
MY='__PKV___J>#"?Y7@`G^4#,)3G``"/X`,0H.$,,(WE,___ZP3`H..N___J
M`0"@XUG__^L<___K&(X``!P!``#LC0``_````!0!```D`0``M(X``.B.``#H
MC@``Q#<``,0W``"`C@``8`D``%B.``#<-```)(X``(R,``#4C0``1(T``+PS
M```H`0``F#4```"PH.,`X*#C!!"=Y`T@H.$$("WE!``MY1R@G^48,(_B`Z"*
MX``PH.,$,"WE#`"?Y0``FN<K___KCO[_ZS"+```P`0``%#"?Y10@G^4#,(_@
M`B"3YP``4N,>_R\!E/[_ZAB+`````0``+`"?Y2PPG^4L()_E``"/X`,PC^``
M`%/A`B"/X![_+P$8,)_E`S"2YP``4^,>_R\!$_\OX6R,``!HC```Y(H```0!
M```X`)_E.#"?Y0``C^`#,(_@`#!#X*,?H.$H()_E0Q&!X,$0L.$"((_@'O\O
M`1@PG^4#,)+G``!3XQ[_+P$3_R_A+(P``"B,``"4B@``"`$``$PPG^5,()_E
M`S"/X``PT^4"((_@``!3XQ[_+Q$00"WI-#"?Y0,PDN<``%/C`@``"B@PG^4#
M`)_G^O[_Z\K__^L!(*#C&#"?Y0,PC^``(,/E$("]Z-R+``!8B@``+`$``&R+
M``"<BP``T/__ZO!'+>F\,)_EO""?Y0,PC^`"()/G`("2Y0``6.,G```*`%#0
MY0``5>,]`%43`5"@$P!0H`,3```:`$"8Y0``5.,.```*`9"@X0!PH.$(8*#A
M!2"@X0<0H.$$`*#AN/[_ZP``4.,"```:!3#4YST`4^,+```*!$"VY0``5./S
M__\:!`"@X?"'O>@`4*#A`3#UY0``4^,]`%,3^___&@!01>#D___J"&!&X`%0
MA>)&8:#A!4"$X`0`H.$`8(GE\(>]Z`A`H.'M___J\(D``!@!```00"WIC""?
MY8PPG^4"((_@<-!-X@,PDN<-$*#A`$"@X0`PD^5L,(WE`#"@XWC^_^L``%#C
M``"@$P0``!H0,)WE#SH#X@H*4^,!"5,3"@``"D@@G^5`,)_E`B"/X`,PDN<`
M()/E;#"=Y0(@,^``,*#C!P``&G#0C>(0@+WH`A"@XP0`H.$=_O_K$`]OX:`"
MH.'N___J4O[_ZR")```<`0``U(@``'!`+>ET(9_E=#&?Y0(@C^`#,)+G@-!-
MX@!04.(`,)/E?#"-Y0`PH.,"```*`##5Y0``4^,*```:2"&?Y4`QG^4"((_@
M`S"2YP`@D^5\,)WE`B`SX``PH.-'```:@-"-XG"`O>C/_?_K`$!0XO'__PH$
M`*#A3_[_ZP``4.,P```*$R#0Y1,P@.(N`%+C`@``&@$@T^4``%+C]/__"A,@
MT.4N`%+C*P``"@4`H.$(,(WE^_W_ZP@PG>4`8*#A`P"@X0PPC>7V_?_K`""&
MX`(@@N("`*#A"""-Y17^_^L`8*#A##"=Y0(0H.,$,(WEF#"?Y0@@G>4#,(_@
M`%"-Y3#^_^L&`*#A$!"-XM;]_^L!`'#C!@"@X0,```H@,)WE#SH#X@$)4^,2
M```*X/W_ZP8`H.'#_?_K!`"@X1[^_^L``%#CSO__&@0`H.'M_?_K!0"@X0/^
M_^NW___J`2#3Y2X`4N/0__\:`B#3Y0``4N.___\*S/__ZJ'__^OK___J[_W_
MZWR(```<`0``2(@``.PN``#P0RWI`4"@X20BG^4D,I_E`B"/X`,PDN<4T$WB
M`#"3Y0PPC>4`,*#C`##1Y0!0H.$]`%/C`4"!`@0`H.&T_?_K"!"-X@!@H.$%
M`*#A*O__Z^1QG^4`@%#B!W"/X$(```JK_?_K``!6X3D``)K,,9_E"""=Y0-P
ME^<"(:#A``#5Y0``4.,]`%`3`0"@$P``H`,%```*!0"@X0$P\.4``%/C/0!3
M$_O__QH%`$#@`F"&X@``AN``((WE`&"7Y;C]_^L`()WE``!0XP(`AN<5```*
M`##5Y0`0E^4]`%/C``!3$P(0D><`,,'E!P``"@$`A>(!(('B`3#0Y`(0H.$`
M`%/C/0!3$P$PPN3Y__\:/3"@XP$@H.$`,,'E`3#4Y```4^,!,.+E^___&A0A
MG^4$,9_E`B"/X`,PDN<`()/E##"=Y0(@,^``,*#C.```&A30C>+P@[WH`8!(
MX@$PU.0``%/C`3#HY?O__QKN___JS#"?Y0-PE^<`()?E`#"2Y0``4^,G```*
M`C"@X000L^4(`*#A``!1XP&`B.+Z__\:`P"`X@`QH.&<$)_E`1"/X```D>4`
M`%#C$@``&@$`H.,``('E`P"@X00@C>4`,(WE=/W_ZP"04.+3__\*""&@X0`P
MG>4$$)WE`""-Y9K]_^L`()WE`)"'Y0`PH.,!@(CB"#&)YYW__^H#$*#A`@"@
MX93]_^L`D%#B``"'Y<+__PH((:#A\___Z@.`H.$(,*#CW/__ZE[]_^OHA@``
M'`$``*"&```8`0``R(4``-"&``#P0"WI`7"@X?P0G^4!VDWB^#"?Y1303>(!
M$(_@`S"1YP!@H.$!"HWB`#"3Y0PP@.4`,*#C#`"`XM0`G^7_+P#C#!"-X@``
MC^!@_?_K`#!0X@8``-H!($/B`D"-X`P0U.4``%'C%P``&@``4N,4```:<`\=
M[IPPG^4'(*#A`S"?YP80H.$#`)#GZOS_ZX@@G^5X,)_E`B"/X`$:C>(#,)+G
M#!"!X@`@D^4`,)'E`B`SX``PH.,3```:`=J-XA30C>+P@+WH`C"@X0,@H.$O
M$*#C#`"-X@0PC>57_?_K``!0X^+__PIPSQWN,`"?Y080H.$``)_G!#"=Y0``
MG.<,((WB_/S_Z^#__^H5_?_KE(0``!P!``#(*P``/(4``!B$``#(A```$$`M
MZ7!/'>YH()_E:!"?Y0(@C^`!()+G$-!-XEP`G^4,((WE``"?YU0PG^54$)_E
M``"4YP,PC^`!$(_@)OW_ZP#`H.-``)_E0#"?Y0``G^<\()_E/!"?Y0,PC^``
M`)3G`B"/X`@0C>@!$(_@QOS_ZQ#0C>(0@+WH>(,``!`!``!PA```;&L``,`J
M``!(A```I"T``#`6``"L*@``<`\=[C0@G^4TP)_E`B"/X`P@DN<(T$WB*!"?
MY00@C>4!$)_G(#"?Y0$`D.<<$)_E`S"/X`$0C^`(T(WB__S_ZN""```0`0``
MV(,``-1J```H*@``<$`MZ>`@G^4"VDWBW#"?Y2#03>("((_@`S"2YP(:C>(<
M$('B`#"3Y0`P@>4`,*#CV_S_Z[C`G^6X,)_E#,"/X`$0C>@!(`'C`A"@XP,P
MC^`4`(WBWOS_ZP$:C>(!*J#C%`"-XA@0@>+3_/_K`$!0X@!0H+,,``"Z`3"$
MX@,`H.$,,(WEKOS_ZP!04.(&```*`1J-X@PPG>4$(*#A&!"!XG?\_^L`,*#C
M!##%YT@@G^4X,)_E`B"/X`(:C>(#,)+G'!"!X@`@D^4`,)'E`B`SX``PH.,#
M```:!0"@X0+:C>(@T(WB<("]Z)C\_^N$@@``'`$```PJ``#P*0``Y($``+[_
M_^KP3RWI."*?Y4+=3>(T,I_E!-!-X@(@C^``8*#A*`*?Y0,PDN=!S8WB`4"@
MX0``C^`0$(WB/,",X@`PD^4`,(SE`#"@X]/]_^LO$*#C`%"@X08`H.$E_/_K
M``!0XQ(```KH`9_E!A"@X0``C^"*_O_K!@"@X=@AG^7(,9_E`B"/X$$=C>(#
M,)+G/!"!X@`@D^4`,)'E`B`SX``PH.-G```:0MV-X@30C>+PC[WH!`"@X5G\
M_^N<$9_E`1"/X&C\_^L`0%#BY?__"@`PU.6(D9_E``!3XPF0C^`[```*``!5
MXP0```H$$*#A!0"@X8_\_^L``%#C*P``"@0`H.$K_/_K`3!`X@,PA.`#`%3A
M`+"@X0$P@S(``*`S`1"$,@,``#H(``#J`P!1X0``P^4"```*`2!SY2\`4N/Y
M__\*!`"@X1K\_^L`L*#A!@"@X1?\_^L+`(#@`0"`X@$*4..___\J^`"?Y0DP
MH.$``(_@`2J@XP(0H.-!`(WI`$"-Y7P`C>)2_/_K$!"-XGP`C>+X^__K``!0
MXP,``!H@,)WE#SH#X@()4^,5```*M!"?Y0``H.,!$(_@*OS_ZP!`4.*G__\*
M`##4Y0``4^/#__\:``!5XQ8```H`,-7E+@!3XP,```J`0)_E`;"@XP1`C^#5
M___J`3#5Y0``4^/J__\*]___Z@$0H.-\`(WBUOO_ZP``4./D__\:4`"?Y7P0
MC>(``(_@'?[_ZWP`C>+[^__KD/__ZCA`G^4!L*#C!$"/X,'__^H!_/_K@($`
M`!P!```@*0``\"@``!B!``"P*```F"@```PH``"X)P``8"<``#PG```0)P``
M$$`MZ2\0H.,`0*#AJ?O_ZP``4.,!0(`2!`"@X1!`O>C@^__J$$`MZ7PAG^4!
MVDWB>#&?Y1#03>("((_@`1J-X@,PDN<,$('B`#"3Y0`P@>4`,*#C`!!0XC$`
M``H`,-'E``!3XRX```H$$(WELOO_ZP$@@.(!"E+C.@``B@Q`C>($$)WE!`"-
MY00`H.&P^__K!#"=Y0$P0^(#,(3@!`!3X0<``)H`$*#C`@``Z@$00^0#`%3A
M`@``"@`@T^4O`%+C^?__"B\0H.,$`*#A>?O_ZP``4.,E```*!`!0X0`PH(,`
M,,"%!`"@X:[[_^O`()_EN#"?Y0(@C^`!&HWB`S"2YPP0@>(`()/E`#"1Y0(@
M,^``,*#C(P``&@':C>(0T(WB$("]Z(P@G^6`,)_E`B"/X`$:C>(#,)+G#!"!
MX@`@D^4`,)'E`B`SX``PH.,5```:9`"?Y0``C^`!VHWB$-"-XA!`O>B/^__J
M``"@X][__^I(()_E-#"?Y0(@C^`!&HWB`S"2YPP0@>(`()/E`#"1Y0(@,^``
M,*#C`@``&B``G^4``(_@Z___ZHK[_^OH?@``'`$``"Q^``#T?0``@"4``*A]
M```T)0``<$`MZ<`DG^7`-)_E`B"/X+Q4G^4#,)+GN&2?Y0C03>(%4(_@`#"3
MY00PC>4`,*#C!F"/X`T0H.$&`*#AQOS_ZP``4.,.```*C#2?Y0`0G>4#,)7G
M`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK
M___J5&2?Y09@C^`-$*#A!@"@X;#\_^L``%#C#@``"C0TG^4`$)WE`S"5YP`@
MD^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___
MZ@!DG^4&8(_@#1"@X08`H.&:_/_K``!0XPX```K<,Y_E`!"=Y0,PE><`()/E
M`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^JL
M8Y_E!F"/X`T0H.$&`*#AA/S_ZP``4.,.```*A#.?Y0`0G>4#,)7G`""3Y0$Q
M@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J6&.?
MY09@C^`-$*#A!@"@X6[\_^L``%#C#@``"BPSG^4`$)WE`S"5YP`@D^4!,8+@
M!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___Z@1CG^4&
M8(_@#1"@X08`H.%8_/_K``!0XPX```K4,I_E`!"=Y0,PE><`()/E`3&"X`0`
MD^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^JP8I_E!F"/
MX`T0H.$&`*#A0OS_ZP``4.,.```*?#*?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E
M``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J7&*?Y09@C^`-
M$*#A!@"@X2S\_^L``%#C#@``"B0RG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``
M4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___Z@ABG^4&8(_@#1"@
MX08`H.$6_/_K``!0XPX```K,,9_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C
M`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^JT89_E!F"/X`T0H.$&
M`*#A`/S_ZP``4.,.```*=#&?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!
M@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J8&&?Y09@C^`-$*#A!@"@
MX>K[_^L``%#C#@``"APQG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G
M\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___Z@P!G^4-$*#A``"/X-7[_^L`
M$%#B`@``"O@`G^4``(_@D?S_Z_``G^4-$*#A``"/X,S[_^L`$%#B`@``"MP`
MG^4``(_@B/S_Z]0`G^4-$*#A``"/X,/[_^L`$%#B$@``"L``G^4``(_@?_S_
MZ[@@G^5D,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C$```&I@0G^68`)_E
M`1"/X```C^`(T(WB<$"]Z&_\_^J$`)_E#1"@X0``C^"J^__K`!!0XNG__PIP
M`)_E``"/X&;\_^OE___J4/K_ZTQ]```<`0``.'T```PE```8`0``P"0``'`D
M```D)```U",``(PC``#0(@``Z"(``)PB``!0(@``?"$``*@A``!\(0``F"$`
M`)@A``"4(0``N"```/!X``!P(0``U"```$`A``#$(```!.`MY7@@G^5X,)_E
M`B"/X'0`G^4,T$WB`S"2YPT0H.$``(_@`#"3Y00PC>4`,*#C?/O_ZP``4.,%
M```*``#0Y0``4.,P`%`3`0"@`P``H!,!`"#B-""?Y2@PG^4"((_@`S"2YP`@
MD^4$,)WE`B`SX``PH.,!```:#-"-X@3PG>05^O_K&'@``!P!```L(```R'<`
M``\`+>D$X"WE2""?Y4@PG^4"((_@`S"2YPS03>(`,)/E!#"-Y0`PH.,P`)_E
M,,"?Y10PC>(``(_@`#"-Y0P`D.<"$*#C$""=Y0``D.7H^?_K_P"@XS?Z_^N`
M=P``'`$``%QW```@`0```A"@X_!'+>EXX9_E`=A-XG3!G^48T$WB#N"/X`S`
MGN<!2(WB`""@XP`PH.,`P)SE%,"$Y0#`H.,`$(WE`("@X>#Y_^L!`%#B`'#!
MXL<OH.''/R#@`C!3X',P_^8","/@`C!3X`(@PN`#8%#@`G#'X```5^,40(3B
M.```N@B0H.,,4(WB`9!`XP`0H.,&(*#A!S"@X0@`H.$`$(WER?G_ZP$`<>,!
M`'`#,@``"@D@H.$%$*#A"`"@X8SY_^L!`'#C*0``"@<`4.,?``":"`!`X@!`
ME>`<```JL*"?Y0J@C^`"``#J`4!$X@4`5.$6```Z"""@XPH0H.$$`*#A5/G_
MZP``4./V__\:!4!$X`8`E.#$'Z?@>""?Y6PPG^4"((_@`<B-X@,PDN<4P(SB
M`""3Y0`PG.4"(#/@`#"@XQ```!H!V(WB&-"-XO"'O>@!:%;B`'#'X@$`=^,!
M"'8#R?__&@``X.,`$*#AZ?__ZB0`G^4``(_@A___ZQP`G^4``(_@A/__ZY7Y
M_^L0=P``'`$``(AW```,=@``<!X``%0>```00"WI2_G_ZV[Y_^L``%#C``"0
M%1"`O>AP0"WI%"&?Y11!G^44,9_E`B"/X`,PDN<@T$WB!$"/X`!0H.$8$(WB
M!`"@X0`PD^4<,(WE`#"@X\WZ_^L`,%#B`@``"@`@T^4``%+C#@``&M0@G^7,
M,)_E`B"/X`,PDN<`()/E'#"=Y0(@,^``,*#C*0``&@40H.&P`)_E``"/X"#0
MC>)P0+WH>OO_Z@4`H.$0,(WE//G_ZQ`PG>4`8*#A`P"@X10PC>4W^?_K`""&
MX`(@@N("`*#A$""-Y5;Y_^L4,)WE:!"?Y0@PC>5D,)_E`1"/X!`@G>4#,(_@
M!!"-Y0!0C>4"$*#C`&"@X6[Y_^M$()_E+#"?Y0(@C^`#,)+G`""3Y1PPG>4"
M(#/@`#"@XP80H`$$`*`!V/__"D'Y_^M@=0``&!X``!P!```8=0``N!T``'0<
M``!P'```>'0``/!/+>FP%I_E]-!-XJS&G^6L)I_E&`"-Y0$0C^`"()'G#,"/
MX`PPC.(88(SBB$"-XJ#@C>(`()+E[""-Y0`@H.,'`)/H!P"$Z`\`MN@/`*[H
M`P"6Z##`C.*44(WB`P".Z`<`G.@'`(7H6`:?Y2!PC>('$*#A``"/X&WZ_^M(
MII_E`&!0X@J@C^`"```*`##6Y0``4^,@`0`:T/C_Z_/X_^L``%#C>P``"@!@
MD.4``%;C>```"@8`H.'C^/_K@""@X0&P@N(+`*#A`_G_ZP#`UN4`4*#A``!<
MXPN`H!$<`(T5&P$`"N25G^4)D(_@"R"@X0DPH.$"$*#C!0"@X0#`C>49^?_K
M"P!8X0@@H"$+(*`Q`C!+X@L00N`!P/;E`C!#X`(0@>("`%'A`;"#(`*P@S``
M`%SC`E"%XNO__QJ0!9_EH&"-X@``C^`"``#J!`"VY0``4.-?```*!Q"@X33Z
M_^L`4%#B^/__"@`PU>4``%/C]?__"F+Z_^L``%#C\O__"@4`H.'+^/_K`%!0
MXE$```H%`*#AK/C_ZQQ`G>4`8*#A!`"@X:CX_^L`8(;@`6N&X@1@AN(&`*#A
MQ_C_ZP"`H.$0-9_E!B"@X0,PC^`(,(WE!#6?Y0(0H.,#,(_@!#"-Y?@TG^4,
M0(WE`S"/X`!0C>7=^/_K!QV@XP@`H.%*^/_K`0!PXP,``!KU^/_K``"0Y1$`
M4..T```:!Q"@X0@`H.&\^/_K`$!0XC4```JP!)_E&#"=Y0``FN>H))_E`#"3
MY0"`C>4"$*#C``"0Y0(@C^"G^/_K`%"@XXPDG^5@-)_E`B"/X`,PDN<`()/E
M[#"=Y0(@,^``,*#C"P$`&@4`H.'TT(WB\(^]Z(KX_^L`8%#BD0``&@10A>(`
M`)7E``!0XZT```H'$*#AX?G_ZP`P4.+W__\*`##3Y0``4^/T__\*\/__Z@4`
MH.%Z^/_K`%!0XJ[__QH$0(3B`%"4Y0``5>.J__\*`##5Y0``4^-X```*!0"@
MX0+Z_^L``%#C]/__"N___^HP,)WE#SH#X@$)4^/%__\:.%"=Y3#X_^L``%7A
MP?__&C`PG>53,.CG!PU3X[W__QH&`*#A9_C_ZP!0H.&H`Y_E!Q"@X0``C^"X
M^?_K`!!0XHH```H8,)WE``"3Y<W[_^L`D%#BA0``"@D`H.$U^/_K`P!0XP"@
MH.$,``":;!.?Y00`0.(``(G@`1"/X(WX_^L``%#C!0``&@0`6N.Q```*"J")
MX`4P6N4O`%/CK0``"CP#G^4'$*#A``"/X)OY_^L``%#C`P``"@`PT.4P`%/C
M``!3$P0``!H)`*#A`!"@XR?X_^L`<%#B9P``&@03G^4$`Y_E`1"/X```C^!,
M^O_K3/C_Z_0RG^7T(I_E`S"/X`0PC>7L,I_E`B"/X.BBG^7HDI_EZ'*?Y0@`
MC>4,((WE`A"@XP8@H.$%`*#A`("-Y0,PC^!'^/_K"J"/X`F0C^`'<(_@#P``
MZF#X_^L`,)#E$0!3XQ```!HR^/_K`,"@X0%`A.("$*#C"C"@X08@H.$%`*#A
M@!"-Z1"0C>4,0(WE`("-Y3/X_^L'':#C!0"@X:#W_^L!`'#CZO__"@@`H.',
M]__K7`*?Y040H.$``(_@&_K_ZP4`H.%[_O_K8/__Z@-0H.$L___JVO?_ZX`@
MH.$!L(+B]?[_ZO`AG^48,)WE`L":YR`BG^4`,)/E!`"-Y0``G.4"$*#C`B"/
MX`"`C>7V]__K3?__ZF?^_^O\(9_EF#&?Y0(@C^`#,)+G`""3Y>PPG>4"(#/@
M`#"@XUD``!H&`*#A]-"-XO!/O>C8]__J'`"-Y??^_^H-`*#CW??_ZPV`H..X
M89_E4\"@XP!0H.$(L*#A!F"/X!P`C>77_O_J&#"=Y0"0D^5V___JW/W_ZP"0
M4>(`H*#AD___N@"PH.,*(%#B`##)X@<`H.$`L(WEQ??_Z[@0C>(&(*#C!P"@
MX1@0C>6*]__K!@!0XQ@0G>4U```:0SR@X[@@G>5!,T3C`P!2X8#__QI(-03C
MM"#1X0,`4N%\__\:,B!:X@`PR>('`*#A`+"-Y<!`C>*N]__K*""@XP<`H.$$
M$*#A=/?_ZR@`4.,@```:^#"?Y?@0G^4#,(_@!#"-Y?`PG^4!$(_@#!"-Y08@
MH.$"$*#C!0"@X0A`C>4`@(WE`S"/X.BPS>7`]__KD/__ZA@PG>4$H)/E``!:
MXTW__PH*`*#A<??_ZP,`4.-)__^:I!"?Y00`0.(``(K@`1"/X,KW_^L``%#C
M"I"@`4'__^J-]__KA`"?Y0``C^!X_?_K&'0``$QU```<`0``=!L``*QS```D
M'```8!L``%@;```X&@``+!L``"`!```8&P``T'$``'`:```T&@``G!@``-P8
M``!<&````!@``(@:``"H&0``L!D``%0:``"\%P``*!<``!P8```(;P``C!<`
M`-P5``!D&```@!<``#`7```<%P``<$`MZ50BG^54,I_E`B"/X`,PDN<(T$WB
M`#"3Y00PC>4`,*#C<$\=[C@RG^4X`I_E`S"?YPT0H.$#4)3G``"/X&@PU>5I
M,,7EJ?C_ZP``4.,"```*`##0Y3$`4^-E```*S/O_ZP0RG^4#,)_G`U"4Y_P1
MG^4%`*#A`S"@XP$@H.,!$(_@]O;_ZP!04.(,```*X"&?Y1`0E>4"()_G`!"1
MY0(`E.?0(9_E`B"/X/+V_^L0,)7E`!"3Y0@PD>4!!1/C5P``&K01G^4#,*#C
M`1"?YP$@H.,!`)3GI!&?Y0$0C^#?]O_K`%!0X@L```J4`9_E#1"@X0``C^!]
M^/_K$#"5Y0`@4.(`$)/E/@``"G@QG^4#,)_G`P"4Y]?V_^ML,9_E;!&?Y0,P
MG^<!(*#C`U"4YP$0C^`%`*#ANO;_ZU0AG^4`$*#A`B"/X`4`H.'*]O_K`""@
MXT`QG^5``9_E`S"?YPT0H.$#,)3G``"/X&D@P^5?^/_K*%&?Y0``4.,%4(_@
M`$"@X0@`A>41```*!QV@XP0`H.&4]O_K`3"`XA$`4.,!`%,3)```BO@@G^6P
M,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C&@``&@C0C>)P@+WH!`"5Y;C]
M_^L``%#C`$"@X0@`A>7G__\:N`"?Y0``C^#]]O_K`3#0Y0``4^.:__\*E?__
MZJ`PG^4!`*#A`S"/X`0PD^4`$)/EB/G_Z[W__^J(,)_E`S"?YP,`E.?3]O_K
MHO__ZMKV_^MT$)_E`#"@X0$0C^!L`)_E!!"1Y00@H.$`$)'E``"/X./V_^OD
M;```'`$``,QM``#`%```E&T``%`6``!D;0``+!8``#!M````%@``P!,``.QL
M``#8;```L!4``+05``"@;```0!,``/1L``!`:P``$!4``&!L``#4:P``+&P`
M`,P4```00"WI$"&?Y1`QG^4"((_@`$"@X0@!G^40T$WB`S"2YP@0C>(``(_@
M`#"3Y0PPC>4`,*#C_O?_ZP``4.,*```*`##0Y3``4^,``%,3`3"@`P`PH!,!
M,"/B``!4XP`PH`,!,`,2``!3XPH``!JT()_EJ#"?Y0(@C^`#,)+G`""3Y0PP
MG>4"(#/@`#"@XR$``!H0T(WB$("]Z``PU.4``%/C\?__"@0`H.&A^O_K+Q"@
MXP0`C>5#]O_K!#"=Y0``4.,!,(`2`P"@X7KV_^M8$)_E!""@XP$0C^"F]O_K
M``!0X^'__QI$()_E,#"?Y0(@C^`#,)+G`""3Y0PPG>4"(#/@`#"@XP,``!H$
M`*#A$-"-XA!`O>@C^/_J<O;_ZR1J```<`0``-!(``+QI``!,$@``1&D``/!/
M+>E\+)_E?#R?Y0(@C^`#,)+G`!"@X:W?3>(`,)/EK#*-Y0`PH.,`4*#C*""-
MXD``@.*`8('B!,`0Y0C@$.4L-*#A_SP#X@Q$H.$L/(/A"`"`XO](!.(,/(/A
M/N^_Y@0P@^$``%;A!%""Y0#@@N4(,(+E#%""Y1`@@N+M__\:H#"=Y3"PG>60
M0)WE*%"=Y30@G>68@)WE##"-Y10PC>4C/HWB"Z"@X00@C>4<L(WE)!"-Y05P
MH.$$L*#A+)"=Y:3@G>6<8)WEE""=Y0P0G>40@(WE,`"-X@@PC>480(WE(%"-
MY0$``.H%H*#A!$"-Y0!`H.,!,*#A/,"0Y3@0D.4(4+#E=$"`Y01`D.4%$"'@
M"Q`AX`3`+.`'$"'@`L`LX`G`+.`(L*#A`X"@X:$_H.&,,(/A`1"1X`,0@>$(
M,)WE!B"@X0,`4.$.8*#A"G"@X0#@H.,$D)WE<!"`Y>'__QJ9*0?C)!"=Y2!0
MG>4(X)'E`&"1Y0PPD>40D)'E&*"1Y00`D>4NX:#A@BI%XR!PD>4#[X[AILV@
MX0@PD>4*@"G@@,*,X0)0E>`#[X[A!U"5X!RPG>4#@`C@AL*,X28QH.$*@"C@
M!<"<X``_@^$.`"G@"'"<X`8``.`"L)O@"0`@X`JPF^`&/X/A"\"0X#@`G>4#
M4"[@`@"0X`=0!>`.4"7@"0"0X.?-C.`%`)#@[%V`X$``G>480)WE`@"0X`X`
MD.!GX2/@#.`.X`/@+N!LP:#A#@"0X$C@G>5G@2S@`N">X`6`".!G@2C@`^">
MX.4-@.`(X)[@X(V.X%#@G>6A.P[C`N">X&?ACN!E<2S@`'`'X`QP)^`'X)[@
M6'"=Y6`!H.$"<)?@#,"7X&5Q(.`(<`?@97$GX.CMCN`'P)S@[GV,X&#`G>79
M/D;C`L"<X&7!C.!H42#@#E`%X`!0)>`%P)S@:%"=Y6[AH.$"4)7@``"5X&A1
M+N`'4`7@:%$EX.?-C.`%`)#@[%V`X'``G>4"`)#@:`&`X&>!+N`,@`C@#H`H
MX`@`D.#EC8#@>`"=Y6S!H.$"`)#@#@"0X&?A+.`%X`[@9^$NX`X`D.#H[8#@
M@`"=Y0(`D.!G`8#@97$LX`AP!^`,<"?@!P"0X.Y]@."(`)WE:(&@X0(`D.`,
MP)#@90$HX`X``.!E`2#@``"<X`+`E.#G38#@;@$HX`<``.!EP8S@"``@X&=Q
MH.$,`)#@$,"=Y>1=@.!N`2?@`L"<X`0``.`(P)S@;@$@X`P`D.`4P)WEY0V`
MX`+`G.!NX8S@9,$GX`7`#.`'P"S@#L"<X.#MC."HP)WE95&@X0+`G.`'P)S@
M9'$EX`!P!^!D<2?@!\"<X.Y]C."PP)WE`L"<X&3!C.!@027@#D`$X`5`).`$
MP)S@N$"=Y6[AH.$"0)3@!4"4X&!1+N`'4`7@8%$EX`5`E.#`4)WEY\V,X`(@
ME>!@(8+@9P$NX`P``.`.`"#@`""2X,@`G>7L383@`P"0X&S!H.'04)WE#@"0
MX&?A+.`$X"[@Y"V"X`[@D.`#`)7@9P&`X-A0G>7B?8[@9.$LX`+@+N`.X)#@
M8B&@X0,`E>`,`)#@9,$BX."`G>4'P"S@Y^V.X`S`D.#N78S@`P"8X&?!(N`.
MP"S@9`&`X.A`G>4,`)#@;L&@X?"`G>4#X)3@9T$LX`5`).`"X)[@!.">X`-`
MF.#E#8#@^("=Y6=!A.!E<2S@`'`GX.#MCN`'0)3@8`&@X0-PF.`,<)?@`(&=
MY>[-A.!E02#@#D`DX`1`E^`#<)C@97&'X`B!G>5N42#@#%`EX.Q-A.`%<)?@
M;,&@X0-0F.``4)7@$(&=Y>0-A^!N<2S@!'`GX`=0E>#<+`OC`W"8X&YQA^`8
M@9WEX.V%X&11+.``4"7@!5"7X&`!H.$#<)C@#'"7X""!G>7NS87@9%$@X`Y0
M)>`%<)?@`U"8X&11A>`H@9WE;D$@X`Q`).#L?8?@!%"5X&S!H.$#0)C@`$"4
MX#"!G>7G#87@;E$LX`=0)>`%0)3@`U"8X&[AA>`X@9WE9U$LX`!0)>#@383@
M!>">X&`!H.$#4)C@#,"5X$"!G>5G42#@!%`EX`50G.`#P)C@Y.V.X$B!G>5G
MP8S@9'$@X`YP)^#N787@!\"<X&[AH.$#<)C@``"7X%"!G>5D<2[@!7`GX`<`
MD.`#<)C@Y<V,X%B!G>5D08?@97$NX`QP)^#L#8#@!T"4X&S!H.$#<)C@#G"7
MX&"!G>5EX2S@`.`NX.!-A.`.X)?@`S"8X&4Q@^!H@9WEY%V.X&#A+.`;+TCC
M9'&@X03@+N`.,)/@`H"8X&#AA^%@00?@#,"8X`7@#N!P@9WE!.".X0[@G.`"
MP)C@Y3V#X&#!C.!E`8?A94$'X'B!G>4#``#@X^V.X`0`@.%C,:#A94&#X0S`
MD.`"`)C@!P"0X("!G>5E<0/@#D`$X`=`A.'NS8S@`'"4X`)`F.!N`8/A['V'
MX(B!G>5E083@#```X&Y1`^!LP:#A!0"`X6Y1C.&0L9WE!`"0X`=0!>`"0)C@
M;H$,X`-`E.`(4(7A!%"5X`)`F^#G#8#@;D&$X&?AC.%G@0S@F+&=Y0#@#N`(
MX([AX%V%X`1`GN!@`:#A`N";X`S@GN#ES83@9T&`X6>!`."@L9WE!4`$X`A`
MA.$.0)3@`N";X&=QCN!EX8#A98$`X*BQG>4,X`[@".".X>Q-A.`'<)[@;,&@
MX0+@F^``X)[@Y`V'X&5QC.%E@0S@L+&=Y01P!^`(<(?A#N"7X`)PF^!E<8?@
M9%&,X62!#."XL9WE`%`%X`A0A>'@[8[@!W"5X&`!H.$"4)O@#%"5X.[-A^!D
M<8#A9($`X,"QG>4.<`?@"'"'X050E^`"<)O@9'&'X&Y!@.%N@0#@R+&=Y0Q`
M!.`(0(3AUC$,X^Q=A>`'<)3@;,&@X0)`F^``0)3@Y0V'X&YQC.%N@0S@T+&=
MY05P!^`(<(?A!'"7X`)`F^!N083@9>&,X66!#.#8L9WE`.`.X`C@CN'@?8?@
M!.">X&`!H.$"0)O@#,"4X&5!@.'@L9WE98$`X`=`!.`(0(3A#$"4X`+`F^#G
M[8[@95&,X&?!@.%G@0#@Z+&=Y0[`#.`(P(SA[DV$X`50G.!NX:#A`L";X`#`
MG.#D#87@9U&.X6>!#N#PL9WE!%`%X`A0A>$,4)7@`L";X&=QC.!DP8[A9($.
MX/BQG>4`P`S@",",X>!=A>`'P)S@8`&@X0)PF^`.<)?@9.&`X62!`.``LIWE
M!>`.X`C@CN'ES8S@!^">X`*PF^!E(8#A97$`X`P@`N`(@IWE9$&+X`<@@N%B
M.DSC[.V.X`0@DN!LP:#A[DV"X!!RG>5E(2S@`X"8X```F.`.("+@`B"0X`,`
ME^!E`8#@Y%V"X``@H.,8<IWE!""!Y0P@@>44(('E'""!Y20@@>5N(2S@!"`B
MX`(@D.!D0:#A`P"7X`P`D.#E?8+@;L$DX"`BG>4%P"S@#,"0X`,`DN!N`8#@
M*"*=Y67A).`'X"[@#@"0X&?AH.$#()+@Y\V,X`0@DN`P<IWE94$NX`Q`).`$
M0)+@`R"7X.P-@.!L<2[@92&"X#A2G>4`<"?@X$V$X`<@DN!@`:#A`U"5X&QQ
M(.`.X)7@0%*=Y01P)^`'X)[@`U"5X.0M@N!D<2#@;%&%X$C"G>4"<"?@XNV.
MX`=0E>!B(:#A`\"<X&1Q(N``P)S@[@V%X%!2G>4.<"?@!\"<X`-0E>!N<2+@
M9%&%X%A"G>4`<"?@X,V,X`=0E>!@`:#A`T"4X&!RG>4"0)3@["V%X&Y1(.`,
M4"7@!5"4X`-`E^!N083@;'$@X&CBG>4"<"?@XEV%X`=`E.!B(:#A`^">X&QQ
M(N``X)[@Y0V$X'!"G>4%<"?@!^">X`-`E.!E<2+@;,&$X.!-CN!XXIWE`'`G
MX`?`G.!@`:#A`^">X(!RG>4"()[@9>$@X`3@+N`.X)+@`R"7X.3-C.!D<2#@
M92&"X(A2G>4,<"?@[.V.X`<@DN!LP:#A`U"5X&1Q+.```)7@D%*=Y0YP)^`'
M`)#@`U"5X.XM@N!D087@;G$LX)A2G>4"<"?@X@V`X`=`E.!B(:#A`U"5X`Q0
ME>!N<2+@H,*=Y0!P)^`'4)7@`S"<X.!-A.!@H8K@!C"3X&`!(N`$`"#@9)&)
MX&XQ@^``,)/@&*"!Y1"0@>4(`)'E(,"1Y>1=A>```)7@#""2X"`@@>7E/8/@
M.""?Y0`P@>4L,)_E`B"/X`@`@>4#,)+G`""3Y:PRG>4"(#/@`#"@XP$``!JM
MWXWB\(^]Z$KS_^OP:```'`$``*!<```00"WI@`"@XT'S_^M0,(_BT"##X0`0
MH./P(,#A2#"/XM`@P^'X(,#A1#"/XM`@P^'P(<#A0#"/XM`@P^'X(<#A/#"/
MXM`@P^'P(L#A`""@XP`PH.-X$(#E^"+`X?`CP.$0@+WH`2-%9P````")J\WO
M`````/[<NI@`````=E0R$`````#PX=+#`````/!'+>D"8*#A`#"@XP!0H.$H
MX)#E+`"0Y8;!CN`.`%SA``#3X`%PH.$P()7E-!"5Y<8/H.$!```J`2"2X@`0
MH>(L,(7EICZ@X8`Q@^$",)/@H!ZAX'@`E>4HP(7E``!0XS`PA>4T$(7E.*"%
M`B0``!H_`%;C'```V@=`H.$F@Z#A`9!(X@B#A^`$,*#A"@"@X4`@A.(`0)/E
M!."3Y0C`D^4,$)/E$#"#X@(`4^$`0(#E!."`Y0C`@.4,$(#E$`"`XO/__QH#
M0*#A!0"@X8/\_^L(`%3AZ___&D!PA^)`8$;B"7.'X`F=:>`)8X;@!B"@X0<0
MH.$*`*#AQ/+_ZWA@A>7PA[WH0$!@X@8`5.$&0*"A.*"%X@<0H.$$(*#A``"*
MX+KR_^MX,)7E`S"$X$``4^-X,(7E\(>]&`4`H.$$8$;@!'"'X&7\_^O(___J
M\$$MZ0%`H.%_$.#C*#"4Y3!@E.4SC[_FTS'EYP$@@^(X<(3B.`!2XP!0H.$V
M;[_F`Q#'YP(`A^`\``#:`!"@XT`@8N)Q\O_K!`"@X5#\_^LX(*#C`!"@XP<`
MH.%K\O_K!`"@X7!@A.5T@(3E2/S_ZP,PU.4$`*#A`##%Y;(PU.$!,,7E`#"4
MY2,TH.$",,7E`#"4Y0,PQ>4+,-3E!##%Y;HPU.$%,,7E"#"4Y2,TH.$&,,7E
M"#"4Y0<PQ>43,-3E"##%Y;(QU.$),,7E$#"4Y2,TH.$*,,7E$#"4Y0LPQ>4;
M,-3E###%Y;HQU.$-,,7E&#"4Y2,TH.$.,,7E&#"4Y0\PQ>4C,-3E$##%Y;(R
MU.$1,,7E(#"4Y2,TH.$2,,7E(#"4Y1,PQ>7P0;WH1O+_Z@`0H.,X(&+B-/+_
MZ\?__^H(,)_E`S"/X``PD^6,\O_JA%H```A`+>D(@+WH`0`"`$`````)````
M,`````D````$````"0````P````)````/P````D````W````"0```!<````)
M````+P````D````1````"0```#,````)````%0````D````2````"0```!\`
M```)````-@````D````0````"0```"0````)````*@````D`````````````
M`"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN
M84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E
M>&4`+@```%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S
M```O````4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),24\`
M`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?
M1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'
M3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!
M4E]'3$]"04Q?0TQ%04X`````,0```&QS965K(&9A:6QE9`````!R96%D(&9A
M:6QE9`!,1%],24)205)97U!!5$@`4UE35$5-```E,#)X`````"5S)7,E<R5S
M`````'!A<BT`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T
M<GD@>6]U<B!O<&5R871I;VXI"@``4$%42`````!P87)L`````"YP87(`````
M<VAO<G0@<F5A9```)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E
M<R5S=&5M<"TE=2TE=25S`````!@```!P97)L`````#````!005(Z.E!A8VME
M<CHZ5D524TE/3@`````Q+C`V,P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@
M9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````+64``"TM``!5
M4T52`````%5315).04U%`````%1%35!$25(`5$U0`"]T;7``````979A;"`G
M97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@
M;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L
M.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N
M86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B([
M"B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?
M;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*
M?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU
M;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D
M9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?
M<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU
M;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P
M.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-
M04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI
M(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S
M:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L
M($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?
M0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO
M=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD
M9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T
M96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>
M3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I4
M14U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]
M/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@
M)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR
M;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T
M:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M
M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL
M96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F
M(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P
M<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]
M"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9)
M;G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*
M;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T
M<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M
M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0
M?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI
M.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL
M97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;
M0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@
M=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)
M0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF
M("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@
M<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA
M<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N
M("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O
M9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@
M)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%
M(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K
M97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME
M<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,
M15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E
M=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H
M(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S
M970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@
M)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@
M*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B
M=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*
M;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I
M(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]
M?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE
M9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U
M-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE
M;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U
M;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*
M8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*
M?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B
M=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U
M;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*
M;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE
M<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#
M>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R
M96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I
M;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H
M.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC
M<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE
M;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]
M"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE
M("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS
M;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F
M:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL
M96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE
M;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C
M=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL
M96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q
M6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R
M;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@
M7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@
M0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?
M;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE
M("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R
M=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF
M="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@
M:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@
M("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM
M<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@
M<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R
M"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@
M+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q
M("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU
M;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD
M;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I
M=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]
M"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@
M97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N
M)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4
M)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY
M("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-
M4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A
M9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L
M("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@
M9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B
M=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A
M('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E
M("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/
M7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE
M('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO
M9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D
M("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L
M("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@
M=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I
M"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A
M73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?
M;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@
M>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV
M;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I
M;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ
M9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]
M("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?
M97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H
M<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E
M9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI
M('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%
M+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T
M.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF
M("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*
M?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N
M>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O
M7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)
M3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL
M92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@
M/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P
M96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A
M9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB
M961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA
M;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*
M?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@
M*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T
M94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C
M;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E
M;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@
M87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I
M;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M
M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L
M<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I
M9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M
M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M
M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X
M("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H
M+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T
M(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*
M8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN
M960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL
M93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C
M:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P
M96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE
M9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P
M,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB
M*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M
M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U
M=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O
M<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM
M;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*
M?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\
M("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@
M+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L
M(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*
M?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@
M1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR
M97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@
M=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*
M<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y
M;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E
M<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT
M;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(
M86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL
M:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B
M)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE
M*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D
M14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE
M;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I
M8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H
M+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP
M0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B
M7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#
M04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L
M("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I
M<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H
M95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%
M04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I
M<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S
M=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E
M7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F
M:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D
M9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N
M86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL
M;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M
M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.
M5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I
M('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[
M7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O
M+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!]
M(&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES
M>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM
M?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I
M<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M
M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF
M("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G
M;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@
M*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E
M9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W
M9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D
M<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF
M("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI]
M(&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H
M(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@
M>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%
M35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!
M4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)]
M.PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%
M04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO
M9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`
M7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H
M($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL
M('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI
M8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@
M;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?
M<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#
M86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I
M;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P
M<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@
M:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T52
M4D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,`````0T%#2$4``$`````)````
M,`````D````$````"0````P````)````/P````D````W````"0```!<````)
M````+P````D````1````"0```#,````)````%0````D````2````"0```!\`
M```)````-@````D````0````"0```"0````)````*@````D`````````````
M`-B+_W\!``````````0````0`````0```$=.50```````P````(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#$%```7!0```$````F`P```0```#8#```!````0`,`
M``P```"@#0``#0```(A%```9````O)T``!L````$````&@```,"=```<````
M!````/7^_V^T`0``!0```'P&```&````S`$```H```!T`P``"P```!`````5
M``````````,```#,G@```@```.`!```4````$0```!<```#`"P``$0```.@*
M```2````V````!,````(````'@````@```#[__]O`0``"/[__V^("@``____
M;P(```#P__]O\`D``/K__V\.````````````````````````````````````
M`````````````````````,2=`````````````*P-``"L#0``K`T``*P-``"L
M#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T``*P-
M``"L#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T`
M`*P-``"L#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T``*P-``"L#0``
MK`T``*P-``"L#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T``*P-``"L
M#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T``*P-``"L#0``K`T`````
M````````````````````````````````````````````````````````````
M``````"0$`````````2@```*4$%2+G!M"@````!L20``@$8```````!`1P``
M1$<``&!)``"(1@``:$D```````!,20``5$D```````!T20``1T-#.B`H36%G
M96EA(#$U+C$N,"TQ+FUG83$P*2`Q-2XQ+C``03(```!A96%B:0`!*`````4W
M+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N
M;F]T92YG;G4N8G5I;&0M:60`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N
M<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`
M+F5H7V9R86UE`"YN;W1E+D%"22UT86<`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T
M<FEB=71E<P``````````````````````````````````````````````````
M````"P````<````"````=`$``'0!```D```````````````$`````````!X`
M```!`````@```)@!``"8`0``&0```````````````0`````````F````]O__
M;P(```"T`0``M`$``!@````$``````````0````$````,`````L````"````
MS`$``,P!``"P!```!0````,````$````$````#@````#`````@```'P&``!\
M!@``=`,``````````````0````````!`````____;P(```#P"0``\`D``)8`
M```$``````````(````"````30```/[__V\"````B`H``(@*``!@````!0``
M``(````$`````````%P````)`````@```.@*``#H"@``V`````0`````````
M!`````@```!E````"0```$(```#`"P``P`L``.`!```$````%0````0````(
M````;@````$````&````H`T``*`-```,```````````````$`````````&D`
M```!````!@```*P-``"L#0``Y`(`````````````!`````0```!T`````0``
M``8```"0$```D!```/@T``````````````@`````````>@````$````&````
MB$4``(A%```(```````````````$`````````(`````!`````@```)!%``"0
M10``^$$`````````````!`````````"(`````0``<((```"(AP``B(<```@`
M```,``````````0`````````DP````$````"````D(<``)"'```$````````
M```````$`````````)T````'`````@```)2'``"4AP``(```````````````
M!`````````"K````#@````,```"\G0``O(T```0```````````````0````$
M````MP````\````#````P)T``,"-```$```````````````$````!````,,`
M```&`````P```,2=``#$C0``"`$```4`````````!`````@```#,`````0``
M``,```#,G@``S(X``#0!``````````````0````$````T0````$````#````
M`*````"0``!(```````````````$`````````-<````(`````P```$B@``!(
MD```%```````````````!`````````#<`````0```#``````````2)```"0`
M``````````````$````!````Y0````,``'```````````&R0```S````````
M```````!``````````$````#``````````````"?D```]0``````````````
(`0``````````
